@@ -23,7 +23,7 @@ def send_to_interface(update, retries=5):
                     )
                 },
             )
-            continue
+            break
         except requests.exceptions.ConnectionError as e:
             if not attempt:
                 raise e
